@@ -1,18 +1,9 @@
 #
 # ovirt-engine-setup -- ovirt engine setup
-# Copyright (C) 2013-2014 Red Hat, Inc.
 #
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Copyright oVirt Authors
+# SPDX-License-Identifier: Apache-2.0
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
 #
 
 
@@ -26,6 +17,8 @@ from . import misc
 from . import remote_engine
 from . import scale
 from . import service
+from . import dwh
+from . import dwh_database
 
 
 @util.export
@@ -37,6 +30,8 @@ def createPlugins(context):
     remote_engine.Plugin(context=context)
     scale.Plugin(context=context)
     service.Plugin(context=context)
+    dwh.Plugin(context=context)
+    dwh_database.Plugin(context=context)
 
 
 # vim: expandtab tabstop=4 shiftwidth=4
